Title: [144477] trunk/Source/_javascript_Core
Revision
144477
Author
[email protected]
Date
2013-03-01 11:51:31 -0800 (Fri, 01 Mar 2013)

Log Message

Rename MovHint to MovHintEvent so I can create a NodeType called MovHint

Rubber stamped by Mark Hahnenberg.
        
This is similar to the SetLocal/SetLocalEvent naming scheme, where SetLocal is the
NodeType and SetLocalEvent is the VariableEventKind.

* dfg/DFGVariableEvent.cpp:
(JSC::DFG::VariableEvent::dump):
* dfg/DFGVariableEvent.h:
(JSC::DFG::VariableEvent::movHint):
(JSC::DFG::VariableEvent::id):
(JSC::DFG::VariableEvent::operand):
(VariableEvent):
* dfg/DFGVariableEventStream.cpp:
(JSC::DFG::VariableEventStream::reconstruct):

Modified Paths

Diff

Modified: trunk/Source/_javascript_Core/ChangeLog (144476 => 144477)


--- trunk/Source/_javascript_Core/ChangeLog	2013-03-01 19:23:36 UTC (rev 144476)
+++ trunk/Source/_javascript_Core/ChangeLog	2013-03-01 19:51:31 UTC (rev 144477)
@@ -1,3 +1,22 @@
+2013-03-01  Filip Pizlo  <[email protected]>
+
+        Rename MovHint to MovHintEvent so I can create a NodeType called MovHint
+
+        Rubber stamped by Mark Hahnenberg.
+        
+        This is similar to the SetLocal/SetLocalEvent naming scheme, where SetLocal is the
+        NodeType and SetLocalEvent is the VariableEventKind.
+
+        * dfg/DFGVariableEvent.cpp:
+        (JSC::DFG::VariableEvent::dump):
+        * dfg/DFGVariableEvent.h:
+        (JSC::DFG::VariableEvent::movHint):
+        (JSC::DFG::VariableEvent::id):
+        (JSC::DFG::VariableEvent::operand):
+        (VariableEvent):
+        * dfg/DFGVariableEventStream.cpp:
+        (JSC::DFG::VariableEventStream::reconstruct):
+
 2013-03-01  Raphael Kubo da Costa  <[email protected]>
 
         [JSC] Fix sign comparison warning/error after r144340.

Modified: trunk/Source/_javascript_Core/dfg/DFGVariableEvent.cpp (144476 => 144477)


--- trunk/Source/_javascript_Core/dfg/DFGVariableEvent.cpp	2013-03-01 19:23:36 UTC (rev 144476)
+++ trunk/Source/_javascript_Core/dfg/DFGVariableEvent.cpp	2013-03-01 19:51:31 UTC (rev 144477)
@@ -54,7 +54,7 @@
     case Death:
         out.print("Death(", id(), ")");
         break;
-    case MovHint:
+    case MovHintEvent:
         out.print("MovHint(", id(), ", r", operand(), ")");
         break;
     case SetLocalEvent:

Modified: trunk/Source/_javascript_Core/dfg/DFGVariableEvent.h (144476 => 144477)


--- trunk/Source/_javascript_Core/dfg/DFGVariableEventStream.cpp	2013-03-01 19:23:36 UTC (rev 144476)
+++ trunk/Source/_javascript_Core/dfg/DFGVariableEventStream.cpp	2013-03-01 19:51:31 UTC (rev 144477)
@@ -161,7 +161,7 @@
             iter->value.update(event);
             break;
         }
-        case MovHint:
+        case MovHintEvent:
             if (operandSources.hasOperand(event.operand()))
                 operandSources.setOperand(event.operand(), ValueSource(event.id()));
             break;
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Source/_javascript_Core/dfg/DFGVariableEvent.h	2013-03-01 19:23:36 UTC (rev 144476)
+++ trunk/Source/_javascript_Core/dfg/DFGVariableEvent.h	2013-03-01 19:51:31 UTC (rev 144477)
@@ -57,9 +57,9 @@
     // Death of a node - after this we no longer care about this node.
     Death,
     
     // A MovHint means that a node is being associated with a bytecode operand,
     // but that it has not been stored into that operand.
-    MovHint,
+    MovHintEvent,
     
     // A SetLocalEvent means that a node's value has actually been stored into the
     // bytecode operand that it's associated with.
@@ -169,7 +169,7 @@
         VariableEvent event;
         event.m_id = id;
         event.u.virtualReg = operand;
-        event.m_kind = MovHint;
+        event.m_kind = MovHintEvent;
         return event;
     }
     
@@ -182,7 +182,7 @@
     {
         ASSERT(m_kind == BirthToFill || m_kind == Fill
                || m_kind == BirthToSpill || m_kind == Spill
-               || m_kind == Death || m_kind == MovHint);
+               || m_kind == Death || m_kind == MovHintEvent);
         return m_id;
     }
     
@@ -235,7 +235,7 @@
     
     int operand() const
     {
-        ASSERT(m_kind == SetLocalEvent || m_kind == MovHint);
+        ASSERT(m_kind == SetLocalEvent || m_kind == MovHintEvent);
         return u.virtualReg;
     }
     
@@ -253,7 +253,7 @@
     //   - The GPR or FPR, or a GPR pair.
     // For BirthToSpill, Spill:
     //   - The virtual register.
     // For MovHint, SetLocalEvent:
     //   - The bytecode operand.
     // For Death:
     //   - Unused.
@@ -57,9 +57,9 @@
     Death,
     
-    // A MovHint means that a node is being associated with a bytecode operand,
+    // A MovHintEvent means that a node is being associated with a bytecode operand,
     // but that it has not been stored into that operand.
@@ -253,7 +253,7 @@
     // For BirthToSpill, Spill:
     //   - The virtual register.
-    // For MovHint, SetLocalEvent:
+    // For MovHintEvent, SetLocalEvent:
     //   - The bytecode operand.
     // For Death:

Modified: trunk/Source/_javascript_Core/dfg/DFGVariableEventStream.cpp (144476 => 144477)

